| Title: | Read 'ELAN' Files |
|---|---|
| Description: | The goal of the 'readelan' is to provide a simple way to read data and metadata in files created with the annotation software 'ELAN' <https://archive.mpi.nl/tla/elan> into R as data frames. |
| Authors: | Carl Börstell [aut, cre, cph] (ORCID: <https://orcid.org/0000-0001-7549-4648>) |
| Maintainer: | Carl Börstell <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-06-07 07:21:17 UTC |
| Source: | https://github.com/borstell/readelan |
Reads the controlled vocabularies in ELAN (.eaf/.etf/.ecv) file(s) from a single file or a vector of files as input.
read_cv(file, full_path = FALSE, ecv = TRUE, progress = FALSE)read_cv(file, full_path = FALSE, ecv = TRUE, progress = FALSE)
file |
Path(s) to ELAN file(s) (.eaf/.etf/.ecv) |
full_path |
Whether file names should include full path (defaults to 'FALSE') |
ecv |
Whether to read linked external CVs as well (defaults to 'TRUE') |
progress |
Whether to display a progress bar (defaults to 'FALSE') |
If 'full_path' is set to 'FALSE' (default), the input file names will be listed with their base names only, without the full path.
If 'progress' is set to 'TRUE' (defaults to 'FALSE'), a progress bar is printed to the console to show the iteration across input files.
Data frame of the ELAN media metadata
eaf_file <- system.file("extdata", "example.eaf", package = "readelan", mustWork = TRUE) read_cv(eaf_file, ecv = FALSE) # External CVs (.ecv files) can also be read ecv_file <- system.file("extdata", "syntax.ecv", package = "readelan", mustWork = TRUE) read_cv(ecv_file, ecv = FALSE)eaf_file <- system.file("extdata", "example.eaf", package = "readelan", mustWork = TRUE) read_cv(eaf_file, ecv = FALSE) # External CVs (.ecv files) can also be read ecv_file <- system.file("extdata", "syntax.ecv", package = "readelan", mustWork = TRUE) read_cv(ecv_file, ecv = FALSE)
Reads the annotations in ELAN annotation file(s) (.eaf) from a single file or a vector of files as input.
read_eaf( file, tiers, xpath, fill_times = TRUE, full_path = FALSE, progress = FALSE )read_eaf( file, tiers, xpath, fill_times = TRUE, full_path = FALSE, progress = FALSE )
file |
Path(s) to ELAN annotation file(s) (.eaf) |
tiers |
Specify tiers (TIER_ID or TIER_TYPE) to be read |
xpath |
Specify a detailed XPath for tiers to be read |
fill_times |
Fill empty time slots of child annotations (defaults to 'TRUE') |
full_path |
Whether file names should include full path (defaults to 'FALSE') |
progress |
Whether to display a progress bar (defaults to 'FALSE') |
Specific tiers or tier types can be targeted with a named list, 'tiers = list(tier = "tier1", tier_type = c("tier_type1", "tier_type2"))', or a custom XPath input, ‘xpath = ".//TIER[starts-with(@TIER_ID,’gloss')]"'. A valid 'tier' input will override any simultaneous 'xpath' input.
If 'fill_times' is set to 'TRUE' (default), the time slots of child annotations will be filled with the values of their parent annotations.
If 'full_path' is set to 'FALSE' (default), the input file names will be listed with their base names only, without the full path.
If 'progress' is set to 'TRUE' (defaults to 'FALSE'), a progress bar is printed to the console to show the iteration across input files.
Data frame of ELAN annotations
eaf_file <- system.file("extdata", "example.eaf", package = "readelan", mustWork = TRUE) read_eaf(eaf_file)eaf_file <- system.file("extdata", "example.eaf", package = "readelan", mustWork = TRUE) read_eaf(eaf_file)
Reads the media metadata in ELAN (.eaf) file(s) from a single file or a vector of files as input.
read_media(file, full_path = FALSE, progress = FALSE)read_media(file, full_path = FALSE, progress = FALSE)
file |
Path(s) to ELAN annotation file(s) (.eaf) |
full_path |
Whether file names should include full path (defaults to 'FALSE') |
progress |
Whether to display a progress bar (defaults to 'FALSE') |
If 'full_path' is set to 'FALSE' (default), the input file names will be listed with their base names only, without the full path.
If 'progress' is set to 'TRUE' (defaults to 'FALSE'), a progress bar is printed to the console to show the iteration across input files.
Data frame of ELAN media metadata
eaf_file <- system.file("extdata", "example.eaf", package = "readelan", mustWork = TRUE) read_media(eaf_file)eaf_file <- system.file("extdata", "example.eaf", package = "readelan", mustWork = TRUE) read_media(eaf_file)
Reads the tier metadata in ELAN file(s) (.eaf/.etf/.ecv) from a single file or a vector of files as input.
read_tiers(file, full_path = FALSE, progress = FALSE)read_tiers(file, full_path = FALSE, progress = FALSE)
file |
Path(s) to ELAN file(s) (.eaf/.etf/.ecv) |
full_path |
Whether file names should include full path (defaults to 'FALSE') |
progress |
Whether to display a progress bar (defaults to 'FALSE') |
If 'full_path' is set to 'FALSE' (default), the input file names will be listed with their base names only, without the full path.
If 'progress' is set to 'TRUE' (defaults to 'FALSE'), a progress bar is printed to the console to show the iteration across input files.
Data frame of ELAN tier metadata
eaf_file <- system.file("extdata", "example.eaf", package = "readelan", mustWork = TRUE) read_tiers(eaf_file) etf_file <- system.file("extdata", "CLP_annotation_v2-2.etf", package = "readelan", mustWork = TRUE) read_tiers(etf_file)eaf_file <- system.file("extdata", "example.eaf", package = "readelan", mustWork = TRUE) read_tiers(eaf_file) etf_file <- system.file("extdata", "CLP_annotation_v2-2.etf", package = "readelan", mustWork = TRUE) read_tiers(etf_file)